using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using MySql.Data;
using MySql.Data.MySqlClient;

public partial class _404 : System.Web.UI.Page
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        // This page should be loaded when the requested webpage not could be found (404). When this page loads
        // we catch the url that looks something like this: 
        // ?404;http://www.mywebpage.com:80/something/some.htm : and puts this url in the string "query".

        string query = Request.Url.Query.ToString();

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {

            if (query.ToString().EndsWith(".htm"))
            {
                // We create an array list by splitting up the url by the semicolon sign (:) and should therefore
                // get the url in three parts. The first part is 0, the second part is 1 and the third part is 2. 
                // We want to get the information in the third part (2) and this information hopefully has 
                // a corresponding post in our "301Redirect table".

                // Split the url in three parts.
                string[] parts = query.Split(':');

                // Assign the third part (index 2) to the value for a hidden field.
                HiddenUrl.Value = parts[2].ToString();

                // Create a new string that should include the new url.
                string strNewURL = string.Empty;

                // We select the "NewUrl" from the "Redirect" table where the "HiddenUrl.Value" corresponds to
                // the old url "OldUrl" in our "Redirect" table and makes a 301 Redirect to the new url.

                string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
                string sql = "SELECT NewUrl FROM Redirect WHERE OldUrl=@OldUrl";

                // Create a MySqlConnection. The using block is used to call dispose (close) automatically even
                // if there are an exception.
                using (MySqlConnection cn = new MySqlConnection(ConnString))
                {
                    // Create a MySqlCommand.
                    MySqlCommand cmd = new MySqlCommand(sql, cn);

                    // Add parameters.
                    cmd.Parameters.AddWithValue("@OldUrl", HiddenUrl.Value);

                    // The Try/Catch/Finally block is used to handle exceptions.
                    try
                    {
                        // Open the connection.
                        cn.Open();

                        // Execute the select statement and put the value in the "strNewURL" string.
                        strNewURL = Convert.ToString(cmd.ExecuteScalar());

                        // This is the 301 Redirect code
                        Response.Status = "301 Moved Permanently";
                        Response.StatusCode = 301;
                        Response.AddHeader("Location", strNewURL);

                    }
                    catch (MySqlException ex)
                    {
                        Response.Write(ex.Message);
                    }
                    finally
                    {
                        // Dispose the MySqlCommand to avoid memory leakage.
                        cmd.Dispose();
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Response.Write(ex.Message);
        }
    }
}
